@@ -26,7 +26,7 @@
 
 
 __author__ = 'Nick Efford'
-__version__ = '0.4'
+__version__ = '0.5'
 
 
 import collections
@@ -45,18 +45,22 @@ class SimpleSprite(pygame.sprite.Sprite):
     """A basic sprite represented by a single, static image.
 
        A display surface and the path to the image file must be
-       supplied when creating a SimpleSprite.  The background
-       colour (which will be transparent when rendering the sprite)
-       and the initial position can be specified if the defaults
-       are not suitable.
+       supplied when creating a SimpleSprite.  The presence of an
+       alpha channel can be indicated; otherwise, 'colour key'
+       transparency will be assumed.  The colour key and an
+       initial position can be specified if the defaults are
+       not suitable.
     """
 
-    def __init__(self, screen, image_path, background=None, position=None):
+    def __init__(self, screen, image_path,
+                 alpha=False, background=None, position=None):
         """Creates a SimpleSprite for the given Pygame display surface,
            using the image at the given location.
 
-           By default, the colour of the pixel in the top-left corner of
-           the sprite image is assumed to be a background colour that
+           If the image has full alpha transparency, this should be
+           indicated by setting the 'alpha' argument to True; otherwise,
+           it is assumed that the colour of the pixel in the top-left
+           corner of the sprite image is a background colour that
            should be transparent when the sprite is rendered on screen.
            If some other specific colour represents the background, this
            can be provided as a 3-tuple using the 'background' argument.
@@ -70,13 +74,16 @@ class SimpleSprite(pygame.sprite.Sprite):
 
         self.screen = screen
 
-        # Load image and make background transparent
+        if alpha:
+            self.image = pygame.image.load(image_path).convert_alpha()
+        else:
+            # Load image and make background transparent
 
-        self.image = pygame.image.load(image_path).convert()
+            self.image = pygame.image.load(image_path).convert()
 
-        if not background:
-            background = self.image.get_at((0, 0))
-        self.image.set_colorkey(background)
+            if not background:
+                background = self.image.get_at((0, 0))
+            self.image.set_colorkey(background)
 
         # Position the sprite
 
@@ -85,7 +92,7 @@ class SimpleSprite(pygame.sprite.Sprite):
             self.rect.center = position
         else:
             w, h = self.screen.get_size()
-            self.rect.center = (w / 2, h / 2)
+            self.rect.center = (w // 2, h // 2)
 
     def update(self):
         """Updates this sprite.
@@ -151,7 +158,8 @@ class Sprite(pygame.sprite.Sprite):
 
     image_regexp = re.compile('([a-zA-Z]*)_([a-zA-Z]*)_(\d\d)')
 
-    def __init__(self, screen, path, background=None, position=None,
+    def __init__(self, screen, path,
+                 alpha=False, background=None, position=None,
                  state='-', direction='-'):
         """Creates a Sprite object for the given Pygame display surface,
            using the images at the given location.
@@ -159,8 +167,10 @@ class Sprite(pygame.sprite.Sprite):
            The required 'path' argument is either a path to a directory
            or a path to a Zip archive, containing sprite images.
 
-           By default, the colour of the pixel in the top-left corner of
-           each image is assumed to be a background colour that should
+           If the images have full alpha transparency, this should be
+           indicated by setting the 'alpha' argument to True; otherwise,
+           it is assumed that the colour of the pixel in the top-left
+           corner of each sprite image is a background colour that should
            be transparent when the sprite is rendered on screen.  If some
            other specific colour represents the background, this can be
            provided as a 3-tuple using the 'background' argument.
@@ -176,6 +186,7 @@ class Sprite(pygame.sprite.Sprite):
         super().__init__()
 
         self.screen = screen
+        self.alpha = alpha
         self.background = background
         self.state = state
         self.direction = direction
@@ -202,14 +213,17 @@ class Sprite(pygame.sprite.Sprite):
             self.rect.center = position
         else:
             w, h = self.screen.get_size()
-            self.rect.center = (w / 2, h / 2)
+            self.rect.center = (w // 2, h // 2)
 
     def _load_from_dir(self, path):
         contents = sorted(os.listdir(path))
         for (state, direction, _), name in self._find_images(contents):
             image_path = os.path.join(path, name)
-            image = pygame.image.load(image_path).convert()
-            self._set_background(image)
+            if self.alpha:
+                image = pygame.image.load(image_path).convert_alpha()
+            else:
+                image = pygame.image.load(image_path).convert()
+                self._set_background(image)
             self.images[state][direction].append(image)
 
     def _load_from_zip(self, path):
@@ -218,8 +232,11 @@ class Sprite(pygame.sprite.Sprite):
         for (state, direction, _), name in self._find_images(contents):
             data = archive.open(name).read()
             source = io.BytesIO(data)
-            image = pygame.image.load(source).convert()
-            self._set_background(image)
+            if self.alpha:
+                image = pygame.image.load(source).convert_alpha()
+            else:
+                image = pygame.image.load(source).convert()
+                self._set_background(image)
             self.images[state][direction].append(image)
 
     def _find_images(self, names):
@@ -277,7 +294,7 @@ class Sprite(pygame.sprite.Sprite):
         if self.counter == 0:
             self.counter = self.anim_delay
             self.frame += 1
-            if self.frame == len(self.sequence):
+            if self.frame >= len(self.sequence):
                 self.frame = 0
             self.image = self.sequence[self.frame]
 
