@@ -2,7 +2,7 @@
 #
 # You can move the sprite around the screen using the arrow keys.
 #
-# Copyright (c) 2011 Nick Efford <nick.efford (at) gmail.com>
+# Copyright (c) 2011-12 Nick Efford <nick.efford (at) gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -23,6 +23,7 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
+import argparse
 import pygame
 
 from easypg.colours import GREY
@@ -33,8 +34,8 @@ from easypg.utils import create_surface, read_arrow_keys
 
 class ExampleSprite(SimpleSprite):
 
-    def __init__(self, screen, image_filename):
-        super().__init__(screen, image_filename)
+    def __init__(self, screen, image_filename, alpha=False):
+        super().__init__(screen, image_filename, alpha)
 
     def move(self):
         dx, dy = read_arrow_keys()
@@ -55,9 +56,9 @@ class ExampleSprite(SimpleSprite):
 
 class ExampleWindow(Window):
 
-    def __init__(self, size, filename):
+    def __init__(self, size, filename, alpha=False):
         super().__init__(size, title='SimpleSprite Example')
-        sprite = ExampleSprite(self.screen, filename)
+        sprite = ExampleSprite(self.screen, filename, alpha)
         self.sprites = pygame.sprite.Group(sprite)
 
     def update(self):
@@ -66,13 +67,21 @@ class ExampleWindow(Window):
         self.sprites.draw(self.screen)
 
 
+def parse_command_line():
+    parser = argparse.ArgumentParser(
+     description='Moves a sprite around the screen with the arrow keys.')
+
+    parser.add_argument('-a', '--alpha', action='store_true', dest='alpha',
+     help='sprite image has alpha transparency')
+    parser.add_argument('image', help='filename of sprite image')
+
+    return parser.parse_args()
+
+
 if __name__ == '__main__':
-    import sys
-    if len(sys.argv) > 1:
-        pygame.init()
-        size = (640, 480)
-        window = ExampleWindow(size, sys.argv[1])
-        background = create_surface(size, GREY)
-        window.display(background)
-    else:
-        print('Usage: python3 simplesprite.py <image file>', file=sys.stderr)
+    args = parse_command_line()
+    pygame.init()
+    size = (640, 480)
+    window = ExampleWindow(size, args.image, args.alpha)
+    background = create_surface(size, GREY)
+    window.display(background)
